@@ -1037,120 +1037,6 @@ prepare_auxformula <- function(formula, par = NULL, rsv_pars = NULL) {
   out
 }
 
-dpars <- function() {
-  # names of distributional parameters
-  c("mu", "sigma", "shape", "nu", "phi", "kappa", "beta", "xi",
-    "zi", "hu", "zoi", "coi", "disc", "bs", "ndt", "bias", 
-    "quantile", "alpha", "theta")
-}
-
-links_dpars <- function(dp) {
-  # link functions for distributional parameters
-  switch(dp,
-    mu = "identity",
-    sigma = c("log", "identity"), 
-    shape = c("log", "identity"),
-    nu = c("logm1", "identity"), 
-    phi = c("log", "identity"),
-    kappa = c("log", "identity"), 
-    beta = c("log", "identity"),
-    zi = c("logit", "identity"), 
-    hu = c("logit", "identity"),
-    zoi = c("logit", "identity"), 
-    coi = c("logit", "identity"), 
-    disc = c("log", "identity"),
-    bs = c("log", "identity"), 
-    ndt = c("log", "identity"),
-    bias = c("logit", "identity"),
-    quantile = c("logit", "identity"),
-    xi = c("log1p", "identity"),
-    alpha = c("identity", "log"),
-    theta = c("identity"), 
-    stop2("Parameter '", dp, "' is not supported.")
-  )
-}
-
-valid_dpars <- function(family, ...) {
-  # get valid auxiliary parameters for a family
-  UseMethod("valid_dpars")
-}
-
-#' @export
-valid_dpars.default <- function(family, bterms = NULL, ...) {
-  if (is.family(family) && !is.null(family[["dpars"]])) {
-    # some families have dpar names that depend on the data
-    return(family$dpars)
-  }
-  x <- c(
-    mu = TRUE,
-    sigma = has_sigma(family),
-    shape = has_shape(family), 
-    nu = has_nu(family, bterms = bterms), 
-    phi = has_phi(family),
-    kappa = has_kappa(family),
-    beta = has_beta(family),
-    zi = is_zero_inflated(family, zi_beta = TRUE), 
-    hu = is_hurdle(family, zi_beta = FALSE),
-    zoi = is_zero_one_inflated(family),
-    coi = is_zero_one_inflated(family),
-    bs = is_wiener(family), 
-    ndt = has_ndt(family), 
-    bias = is_wiener(family), 
-    disc = is_ordinal(family),
-    quantile = is_asym_laplace(family),
-    alpha = has_alpha(family),
-    xi = has_xi(family)
-  )
-  names(x)[x]
-}
-
-#' @export
-valid_dpars.mixfamily <- function(family, ...) {
-  out <- lapply(family$mix, valid_dpars, ...)
-  for (i in seq_along(out)) {
-    out[[i]] <- paste0(out[[i]], i)
-  }
-  c(unlist(out), paste0("theta", seq_along(out)))
-}
-
-#' @export
-valid_dpars.brmsterms <- function(family, ...) {
-  valid_dpars(family$family, bterms = family, ...)
-}
-
-is_dpar_name <- function(dpars, family = NULL, ...) {
-  # check if provided names of auxiliar parameters are valid
-  # Args:
-  #   dpars: character vector to be checked
-  #   family: the model family
-  #   ...: further arguments passed to valid_dpars
-  dpars <- as.character(dpars)
-  if (!length(dpars)) {
-    return(logical(0))
-  }
-  if (is.null(family)) {
-    patterns <- paste0("^", dpars(), "[[:digit:]]*$")
-    .is_dpar_name <- function(dpar, ...) {
-      any(ulapply(patterns, grepl, x = dpar))
-    }
-    out <- ulapply(dpars, .is_dpar_name)
-  } else {
-    out <- dpars %in% valid_dpars(family, ...)
-  }
-  as.logical(out)
-}
-
-dpar_class <- function(dpar) {
-  # class of a distributional parameter
-  sub("[[:digit:]]*$", "", dpar)
-}
-
-dpar_id <- function(dpar) {
-  # id of a distributional parameter
-  out <- get_matches("[[:digit:]]+$", dpar, simplify = FALSE)
-  ulapply(out, function(x) ifelse(length(x), x, ""))
-}
-
 validate_formula <- function(formula, ...) {
   # incorporate additional arguments into the model formula
   UseMethod("validate_formula")
