@@ -51,7 +51,7 @@ test_that("brm produces expected errors", {
   # ordinal models
   expect_error(brm(rating ~ treat + (cs(period)|subject),
                    data = inhaler, family = categorical()), 
-               "Category specific effects are only meaningful")
+               "Category specific effects require families")
   
   # families and links
   expect_error(brm(y ~ x, dat, family = gaussian("logit")), 
